@@ -7,7 +7,7 @@ from typing import TYPE_CHECKING
 
 from .common import maybe_declare
 from .compression import compress
-from .connection import is_connection, maybe_channel
+from .connection import PooledConnection, is_connection, maybe_channel
 from .entity import Exchange, Queue, maybe_delivery_mode
 from .exceptions import ContentDisallowed
 from .serialization import dumps, prepare_accept_content
@@ -51,7 +51,7 @@ class Producer:
     #: Default compression method.  Disabled by default.
     compression = None
 
-    #: By default, if a defualt exchange is set,
+    #: By default, if a default exchange is set,
     #: that exchange will be declare when publishing a message.
     auto_declare = True
 
@@ -124,6 +124,7 @@ class Producer:
                 content_type=None, content_encoding=None, serializer=None,
                 headers=None, compression=None, exchange=None, retry=False,
                 retry_policy=None, declare=None, expiration=None, timeout=None,
+                confirm_timeout=None,
                 **properties):
         """Publish message to the specified exchange.
 
@@ -155,6 +156,8 @@ class Producer:
                 Default is no expiration.
             timeout (float): Set timeout to wait maximum timeout second
                 for message to publish.
+            confirm_timeout (float): Set confirm timeout to wait maximum timeout second
+                for message to confirm publishing if the channel is set to confirm publish mode.
             **properties (Any): Additional message properties, see AMQP spec.
         """
         _publish = self._publish
@@ -182,16 +185,18 @@ class Producer:
                 declare.append(self.exchange)
 
         if retry:
+            self.connection.transport_options.update(retry_policy)
             _publish = self.connection.ensure(self, _publish, **retry_policy)
         return _publish(
             body, priority, content_type, content_encoding,
             headers, properties, routing_key, mandatory, immediate,
-            exchange_name, declare, timeout
+            exchange_name, declare, timeout, confirm_timeout, retry, retry_policy
         )
 
     def _publish(self, body, priority, content_type, content_encoding,
                  headers, properties, routing_key, mandatory,
-                 immediate, exchange, declare, timeout=None):
+                 immediate, exchange, declare, timeout=None, confirm_timeout=None, retry=False, retry_policy=None):
+        retry_policy = {} if retry_policy is None else retry_policy
         channel = self.channel
         message = channel.prepare_message(
             body, priority, content_type,
@@ -199,7 +204,8 @@ class Producer:
         )
         if declare:
             maybe_declare = self.maybe_declare
-            [maybe_declare(entity) for entity in declare]
+            for entity in declare:
+                maybe_declare(entity, retry=retry, **retry_policy)
 
         # handle autogenerated queue names for reply_to
         reply_to = properties.get('reply_to')
@@ -209,7 +215,7 @@ class Producer:
             message,
             exchange=exchange, routing_key=routing_key,
             mandatory=mandatory, immediate=immediate,
-            timeout=timeout
+            timeout=timeout, confirm_timeout=confirm_timeout
         )
 
     def _get_channel(self):
@@ -251,6 +257,12 @@ class Producer:
         exc_val: BaseException | None,
         exc_tb: TracebackType | None
     ) -> None:
+        # In case the connection is part of a pool it needs to be
+        # replaced in case of an exception
+        if self.__connection__ is not None and exc_type is not None:
+            if isinstance(self.__connection__, PooledConnection):
+                self.__connection__._pool.replace(self.__connection__)
+
         self.release()
 
     def release(self):
