@@ -60,7 +60,7 @@ class newstr(str):
 
 class test_safe_str:
 
-    def setup(self):
+    def setup_method(self):
         self._encoding = self.patching('sys.getfilesystemencoding')
         self._encoding.return_value = 'ascii'
 
